==> CanvasScraper-0.3.8.6dev.tar.gz: CanvasScraper-0.3.8.6dev/canvasscraper/fileops/DirMaker.py <==
import os
from canvasscraper.fileops.Downloader import Downloader


class DirMaker:

    def __init__(self, formattype, root_dir):
        self.root_dir = root_dir
        self.formattype = formattype
        self.new_base_dir = self.root_dir + "/Courses"

    def __make_base_dir(self):
        try:
            os.mkdir(self.new_base_dir)
        except FileExistsError:
            print("Base Folder Already Exists!")

    def __make_course_dir(self, course_name):
        try:
            os.makedirs(self.new_base_dir + f"/{course_name}")
        except FileExistsError:
            print("Folder Already Exists for this Course!")

    def __make_page_dir(self, course_name, page_name):
        try:
            os.chdir(self.new_base_dir + f"/{course_name}")
        except FileNotFoundError:
            self.__make_course_dir(course_name)
            print("Creating Course Folder, First")
        try:
            os.mkdir(self.new_base_dir + f"/{course_name}/{page_name}")
        except FileExistsError:
            print("Folder Already Exists for this Page!")

    def save_course(self, course_obj):
        self.__make_base_dir()
        if course_obj.has_pages:
            print(f"{course_obj.name} has pages, making Course directory")
            self.__make_course_dir(course_obj.name)
            for name, obj in course_obj.pages.items():
                if obj.has_vids():
                    print(f"Page: {name} has links, downloading content...")
                    for vid in obj.videos:
                        # print(f"D/L {vid.course} video on {vid.page}:\n{vid.name} at {vid.url}")
                        if self.formattype is 'mp4':
                            print(f"Downloading Video from: {vid.url}")
                            Downloader.download_as_video(vid, os.getcwd())
                        elif self.formattype is 'mp3':
                            print(f"Downloading Audio from: {vid.url}")
                            Downloader.download_as_mp3(vid, os.getcwd())
                else:
                    print(f"Page: {name} has no videos, nothing to save!")
        else:
            print(f"{course_obj.name} has no pages, nothing to save!")

    def save_all(self, course_arr):

        for course in course_arr:
            self.save_course(course)

==> CanvasScraper-0.3.8.7dev.tar.gz: CanvasScraper-0.3.8.7dev/canvasscraper/fileops/DirMaker.py <==
import os
from canvasscraper.fileops.Downloader import Downloader


class DirMaker:

    def __init__(self, formattype, root_dir):
        self.root_dir = root_dir
        self.formattype = formattype
        self.new_base_dir = self.root_dir + "/Courses"

    def __make_base_dir(self):
        try:
            os.mkdir(self.new_base_dir)
        except FileExistsError:
            print("Base Folder Already Exists!")

    def __make_course_dir(self, course_name):
        try:
            os.makedirs(self.new_base_dir + f"/{course_name}")
        except FileExistsError:
            print("Folder Already Exists for this Course!")

    def __make_page_dir(self, course_name, page_name):
        try:
            os.chdir(self.new_base_dir + f"/{course_name}")
        except FileNotFoundError:
            self.__make_course_dir(course_name)
            print("Creating Course Folder, First")
        try:
            os.mkdir(self.new_base_dir + f"/{course_name}/{page_name}")
        except FileExistsError:
            print("Folder Already Exists for this Page!")

    def save_course(self, course_obj):
        self.__make_base_dir()
        if course_obj.has_pages:
            print(f"{course_obj.name} has pages, making Course directory")
            self.__make_course_dir(course_obj.name)
            for name, obj in course_obj.pages.items():
                if obj.has_vids():
                    print(f"\tPage: {name} has links, downloading content...")
                    for vid in obj.videos:
                        # print(f"D/L {vid.course} video on {vid.page}:\n{vid.name} at {vid.url}")
                        if self.formattype is 'mp4':
                            print(f"\t\tDownloading Video from: {vid.url}")
                            Downloader.download_as_video(vid, os.getcwd())
                        elif self.formattype is 'mp3':
                            print(f"\t\tDownloading Audio from: {vid.url}")
                            Downloader.download_as_mp3(vid, os.getcwd())
                else:
                    print(f"\tPage: {name} has no videos, nothing to save!")
        else:
            print(f"{course_obj.name} has no pages, nothing to save!")

    def save_all(self, course_arr):

        for course in course_arr:
            self.save_course(course)
